from setuptools import setup

setup(name='littleutils',
      version='0.2.2',
      description='Small personal collection of python utility functions',
      url='https://github.com/alexmojaki/littleutils',
      author='Alex Hall',
      author_email='alex.mojaki@gmail.com',
      license='MIT',
      packages=['littleutils'],
      zip_safe=False)